gsa_results: Gene set analysis result data
Description
This data set contains gene set analysis results, as returned by the runGSA function, that is used as example data for downstream functions. The input data to runGSA was randomly generated and is accessible through data(gsa_input).
Format
A list where each element is an object of class GSAres, as returned by runGSA.